@@ -2,7 +2,7 @@ context("testing oadoi_fetch")
 
 test_that("oadoi_fetch returns", {
   skip_on_cran()
-  email <- "test@test.com"
+  email <- "najko.jahn@gmail.com"
   a <- oadoi_fetch(dois = "10.7717/peerj.2323", email)
   b <- oadoi_fetch(dois = c("10.1038/ng.919", "10.1105/tpc.111.088682"),
                    email)
@@ -13,6 +13,7 @@ test_that("oadoi_fetch returns", {
   e <- oadoi_fetch("10.1016/j.vaccine.2014.04.085", email)
   f <- oadoi_fetch(dois = c("10.1016/0898-1221(94)90121-x",
                            "10.1093/ref:odnb/20344"), email)
+  g <- oadoi_fetch(dois = c("10.7717/peerj.2323", ""), email)
 
 
   # correct classes
@@ -22,6 +23,8 @@ test_that("oadoi_fetch returns", {
   expect_is(d, "tbl_df")
   expect_is(e, "tbl_df")
   expect_is(f, "tbl_df")
+  expect_is(g, "tbl_df")
+
 
 
   # correct dimensions
@@ -30,6 +33,7 @@ test_that("oadoi_fetch returns", {
   expect_equal(nrow(c), 1)
   expect_equal(nrow(d), 2)
   expect_equal(nrow(e), 1)
+  expect_equal(nrow(g), 1)
 
 
 
@@ -37,6 +41,8 @@ test_that("oadoi_fetch returns", {
   expect_warning(oadoi_fetch(dois = c("ldld", "10.1038/ng.3260"), email))
   # wrong .progress value
   expect_warning(oadoi_fetch("10.1038/ng.3260", email, .progress = "TEXT"))
+  # empty character
+  expect_warning(oadoi_fetch(dois = c("10.7717/peerj.2323", ""), email))
   # missing email address
   expect_error(oadoi_fetch("10.1038/ng.3260"))
 })
